@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::AddID;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v1.1.1');
+use version; our $VERSION = version->declare('v1.1.2');
 
 use Sys::Syslog qw{:standard :macros};
 
@@ -24,7 +24,7 @@ __END__
 
 =head1 NAME
 
-  Authentication Milter - AddID Module
+  Authentication-Milter - AddID Module
 
 =head1 DESCRIPTION
 
