@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::Auth;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-use version; our $VERSION = version->declare('v1.1.1');
+use version; our $VERSION = version->declare('v1.1.2');
 
 use Sys::Syslog qw{:standard :macros};
 
@@ -66,7 +66,7 @@ __END__
 
 =head1 NAME
 
-  Authentication Milter - Auth Module
+  Authentication-Milter - Auth Module
 
 =head1 DESCRIPTION
 
